@@ -13,8 +13,8 @@ class Article(BaseArticle):
     """Example of custom article: add an author field"""
     author = models.ForeignKey(User, blank=True, default=None, null=True)
 
-    def __unicode__(self):
-        return u"{0} - {1}".format(self.author, super(Article, self).__unicode__())
+    def __str__(self):
+        return "{0} - {1}".format(self.author, super(Article, self).__str__())
 
 
 class ModeratedArticle(Article):
@@ -27,8 +27,8 @@ class ModeratedArticle(Article):
         """return true if the user can publish the article: only superuser is allowed"""
         return user.is_superuser
 
-    def __unicode__(self):
-        return super(ModeratedArticle, self).__unicode__()
+    def __str__(self):
+        return super(ModeratedArticle, self).__str__()
 
 
 class PrivateArticle(Article):
@@ -49,5 +49,5 @@ class PrivateArticle(Article):
         """True if user can publish: here only the article author"""
         return self.author == user
 
-    def __unicode__(self):
-        return super(PrivateArticle, self).__unicode__()
+    def __str__(self):
+        return super(PrivateArticle, self).__str__()
