@@ -10,14 +10,15 @@ from coop_cms.apps.rss_sync import models, views
 from coop_cms.apps.rss_sync.forms import RssSourceAdminForm, RssItemAdminForm
 
 
+@admin.register(models.RssSource)
 class RssSourceAdmin(admin.ModelAdmin):
     """Rss source admin"""
 
     list_display = ('url', 'title', 'last_collect')
     readonly_fields = ('title', 'last_collect')
     fieldsets = (
-        (_(u'Feed'), {'fields': ('url',)}),
-        (_(u'Information'), {'fields': ('title', 'last_collect')}),
+        (_('Feed'), {'fields': ('url',)}),
+        (_('Information'), {'fields': ('title', 'last_collect')}),
     )
     actions = [views.collect_rss_items_action]
 
@@ -30,9 +31,8 @@ class RssSourceAdmin(admin.ModelAdmin):
             })
         return super(RssSourceAdmin, self).get_form(request, obj, **defaults) # pylint: disable=E1002
 
-admin.site.register(models.RssSource, RssSourceAdmin)
-
 
+@admin.register(models.RssItem)
 class RssItemAdmin(admin.ModelAdmin):
     """Rss Item admin"""
     form = RssItemAdminForm
@@ -40,11 +40,9 @@ class RssItemAdmin(admin.ModelAdmin):
     list_filter = ('source', 'processed')
     readonly_fields = ('source', 'link', 'updated', 'processed')
     fieldsets = (
-        (_(u'Actions'), {'fields': ('id',)}),
-        (_(u'Source'), {'fields': ('source', 'link', 'updated')}),
-        (_(u'Content'), {'fields': ('title', 'summary')}),
-        (_(u'CMS'), {'fields': ('processed',)}),
+        (_('Actions'), {'fields': ('id',)}),
+        (_('Source'), {'fields': ('source', 'link', 'updated')}),
+        (_('Content'), {'fields': ('title', 'summary')}),
+        (_('CMS'), {'fields': ('processed',)}),
     )
     actions = [views.create_cms_article_action]
-
-admin.site.register(models.RssItem, RssItemAdmin)
