@@ -2,7 +2,13 @@
 """models"""
 
 from django.db import models
-from django.core.urlresolvers import reverse
+
+from coop_cms.moves import reverse, is_authenticated
+
+
+class TestTag(models.Model):
+    """for unit-testing : test_view_object_m2m_relationships"""
+    name = models.CharField(max_length=100)
 
 
 class TestClass(models.Model):
@@ -17,8 +23,10 @@ class TestClass(models.Model):
 
     other_field = models.CharField(max_length=100)
 
-    def __unicode__(self):
-        return u"Test Object {0}".format(self.id)
+    tags = models.ManyToManyField(TestTag, blank=True)
+
+    def __str__(self):
+        return "Test Object {0}".format(self.id)
 
     def get_list_url(self):
         """for unit-testing"""
@@ -34,7 +42,7 @@ class TestClass(models.Model):
 
     def can_view_object(self, user):
         """for unit-testing"""
-        return user.is_authenticated()
+        return is_authenticated(user)
 
     def can_edit_object(self, user):
         """for unit-testing"""
