@@ -4,7 +4,6 @@
 from django import template
 from django.contrib.contenttypes.models import ContentType
 from django.template import VariableDoesNotExist
-from django.template import Context
 from django.template.loader import get_template
 from django.utils.translation import ugettext as _
 
@@ -13,6 +12,7 @@ from coop_cms.settings import get_navtree_class
 
 register = template.Library()
 
+
 def extract_kwargs(args):
     """args from templatetag args"""
     kwargs = {}
@@ -30,22 +30,22 @@ class NavigationTemplateNode(template.Node):
     def __init__(self, *args, **kwargs):
         super(NavigationTemplateNode, self).__init__()
         self._kwargs = {}
-        for (k, v) in kwargs.items():
-            self._kwargs[k] = template.Variable(v)
+        for (key, value) in kwargs.items():
+            self._kwargs[key] = template.Variable(value)
 
     def resolve_kwargs(self, context):
         """resolve: get value from context or from string"""
         kwargs = {}
-        for (k, v) in self._kwargs.items():
+        for (key, value) in self._kwargs.items():
             try:
-                kwargs[k] = v.resolve(context)
+                kwargs[key] = value.resolve(context)
             except VariableDoesNotExist:
-                kwargs[k] = v.var  # if the variable can not be resolved, thake the value as is
+                kwargs[key] = value.var  # if the variable can not be resolved, take the value as is
 
         if not 'tree' in kwargs:
             kwargs['tree'] = 'default'
 
-        tree, _is_new = get_navtree_class().objects.get_or_create(name=kwargs['tree'])
+        tree = get_navtree_class().objects.get_or_create(name=kwargs['tree'])[0]
         if 'coop_cms_navtrees' in context.dicts[0]:
             context.dicts[0]['coop_cms_navtrees'].append(tree)
         else:
@@ -53,11 +53,9 @@ class NavigationTemplateNode(template.Node):
 
         return kwargs
 
-#----------------------------------------------------------
-
 
 class NavigationAsNestedUlNode(NavigationTemplateNode):
-    """NAvigation as nested ul"""
+    """Navigation as nested ul"""
 
     def __init__(self, **kwargs):
         super(NavigationAsNestedUlNode, self).__init__(**kwargs)
@@ -66,11 +64,17 @@ class NavigationAsNestedUlNode(NavigationTemplateNode):
         """to html"""
         kwargs = self.resolve_kwargs(context)
         tree_name = kwargs.pop('tree', 'default')
-        root_nodes = NavNode.objects.filter(tree__name=tree_name, parent__isnull=True).order_by("ordering")
+        root_nodes = NavNode.objects.filter(tree__name=tree_name)
+        parent = kwargs.pop('parent', None)
+        if parent:
+            root_nodes = root_nodes.filter(parent=parent)
+        else:
+            root_nodes = root_nodes.filter(parent__isnull=True)
+        root_nodes = root_nodes.order_by("ordering")
         total_nodes = root_nodes.count()    
-        return u''.join([
-            node.as_navigation(node_pos=i+1, total_nodes=total_nodes, **kwargs)
-                for (i, node) in enumerate(root_nodes)
+        return ''.join([
+            node.as_navigation(node_pos=i + 1, total_nodes=total_nodes, **kwargs)
+            for (i, node) in enumerate(root_nodes)
         ])
 
 
@@ -81,25 +85,23 @@ def navigation_as_nested_ul(parser, token):
     kwargs = extract_kwargs(args)
     return NavigationAsNestedUlNode(**kwargs)
 
-#----------------------------------------------------------
-
 
 class NavigationBreadcrumbNode(NavigationTemplateNode):
     """Navigation"""
-    def __init__(self, object, **kwargs):
+    def __init__(self, obj, **kwargs):
         super(NavigationBreadcrumbNode, self).__init__(**kwargs)
-        self.object_var = template.Variable(object)
+        self.object_var = template.Variable(obj)
 
     def render(self, context):
         """to html"""
         obj = self.object_var.resolve(context)
-        ct = ContentType.objects.get_for_model(obj.__class__)
+        content_type = ContentType.objects.get_for_model(obj.__class__)
         kwargs = self.resolve_kwargs(context)
         tree_name = kwargs.pop('tree', 'default')
-        nav_nodes = NavNode.objects.filter(tree__name=tree_name, content_type=ct, object_id=obj.id)
+        nav_nodes = NavNode.objects.filter(tree__name=tree_name, content_type=content_type, object_id=obj.id)
         if nav_nodes.count() > 0:
             return nav_nodes[0].as_breadcrumb(**kwargs)
-        return u''
+        return ''
 
 
 @register.tag
@@ -111,26 +113,25 @@ def navigation_breadcrumb(parser, token):
         raise template.TemplateSyntaxError(_("navigation_breadcrumb requires object as argument"))
     return NavigationBreadcrumbNode(args[1], **kwargs)
 
-#----------------------------------------------------------
-
 
 class NavigationChildrenNode(NavigationTemplateNode):
     """Navigation"""
 
-    def __init__(self, object, **kwargs):
+    def __init__(self, obj, **kwargs):
         super(NavigationChildrenNode, self).__init__(**kwargs)
-        self.object_var = template.Variable(object)
+        self.object_var = template.Variable(obj)
 
     def render(self, context):
         """to html"""
         obj = self.object_var.resolve(context)
-        ct = ContentType.objects.get_for_model(obj.__class__)
+        content_type = ContentType.objects.get_for_model(obj.__class__)
         kwargs = self.resolve_kwargs(context)
         tree_name = kwargs.pop('tree', 'default')
-        nav_nodes = NavNode.objects.filter(tree__name=tree_name, content_type=ct, object_id=obj.id)
+        nav_nodes = NavNode.objects.filter(tree__name=tree_name, content_type=content_type, object_id=obj.id)
         if nav_nodes.exists():
             return nav_nodes[0].children_as_navigation(**kwargs)
-        return u''
+        return ''
+
 
 @register.tag
 def navigation_children(parser, token):
@@ -138,28 +139,28 @@ def navigation_children(parser, token):
     args = token.contents.split()
     kwargs = extract_kwargs(args)
     if len(args) < 2:
-        raise template.TemplateSyntaxError(_("navigation_children requires object as argument and optionally tree={{tree_name}}"))
+        raise template.TemplateSyntaxError(
+            _("navigation_children requires object as argument and optionally tree={{tree_name}}")
+        )
     return NavigationChildrenNode(args[1], **kwargs)
 
-#----------------------------------------------------------
-
 
 class NavigationSiblingsNode(NavigationTemplateNode):
     """Navigation"""
 
-    def __init__(self, object, **kwargs):
+    def __init__(self, obj, **kwargs):
         super(NavigationSiblingsNode, self).__init__(**kwargs)
-        self.object_var = template.Variable(object)
+        self.object_var = template.Variable(obj)
 
     def render(self, context):
         obj = self.object_var.resolve(context)
-        ct = ContentType.objects.get_for_model(obj.__class__)
+        content_type = ContentType.objects.get_for_model(obj.__class__)
         kwargs = self.resolve_kwargs(context)
         tree_name = kwargs.pop('tree', 'default')
-        nav_nodes = NavNode.objects.filter(tree__name=tree_name, content_type=ct, object_id=obj.id)
+        nav_nodes = NavNode.objects.filter(tree__name=tree_name, content_type=content_type, object_id=obj.id)
         if nav_nodes.count() > 0:
             return nav_nodes[0].siblings_as_navigation(**kwargs)
-        return u''
+        return ''
 
 
 @register.tag
@@ -171,15 +172,16 @@ def navigation_siblings(parser, token):
         raise template.TemplateSyntaxError(_("navigation_siblings requires object as argument"))
     return NavigationSiblingsNode(args[1], **kwargs)
 
-#----------------------------------------------------------
+
 DEFAULT_NAVROOT_TEMPLATE = 'coop_cms/navigation_node.html'
 
 
 @register.filter
 def render_template_node(node, template_name=""):
     """render to html"""
-    t = get_template(template_name or DEFAULT_NAVROOT_TEMPLATE)
-    return t.render(Context({'node': node}))
+    the_template = get_template(template_name or DEFAULT_NAVROOT_TEMPLATE)
+    return the_template.render({'node': node})
+
 
 class NavigationRootNode(NavigationTemplateNode):
     """Navigation"""
@@ -189,8 +191,17 @@ class NavigationRootNode(NavigationTemplateNode):
         kwargs = self.resolve_kwargs(context)
         tree_name = kwargs.pop('tree', 'default')
         template_name = kwargs.pop('template_name', DEFAULT_NAVROOT_TEMPLATE)
-        root_nodes = NavNode.objects.filter(tree__name=tree_name, parent__isnull=True, in_navigation=True).order_by("ordering")
-        return u''.join([render_template_node(node, template_name) for node in root_nodes])
+        parent = kwargs.pop('parent', None)
+
+        root_nodes = NavNode.objects.filter(tree__name=tree_name, in_navigation=True)
+        if parent:
+            root_nodes = root_nodes.filter(parent=parent)
+        else:
+            root_nodes = root_nodes.filter(parent__isnull=True)
+        root_nodes = root_nodes.order_by("ordering")
+
+        return ''.join([render_template_node(node, template_name) for node in root_nodes])
+
 
 @register.tag
 def navigation_root_nodes(parser, token):
@@ -198,3 +209,9 @@ def navigation_root_nodes(parser, token):
     args = token.contents.split()
     kwargs = extract_kwargs(args)
     return NavigationRootNode(**kwargs)
+
+
+@register.filter
+def get_navigation_node(nav_node_id):
+    """navigation"""
+    return NavNode.objects.get(id=nav_node_id)
